@@ -53,7 +53,7 @@ Gnomoradio::CriteriaCreator::CriteriaCreator ()
 	pack_start(s_window);
 
 	xmlpp::Element *el = 0; // C++ sucks my asshole
-	add_button.signal_clicked().connect(bind(SigC::slot(*this, &Gnomoradio::CriteriaCreator::add_new_input), el));
+	add_button.signal_clicked().connect(bind(sigc::mem_fun(*this, &Gnomoradio::CriteriaCreator::add_new_input), el));
 }
 
 Gnomoradio::CriteriaCreator::~CriteriaCreator ()
@@ -115,8 +115,8 @@ void Gnomoradio::CriteriaCreator::add_new_input (xmlpp::Element *element)
 		inputs.back()->set_criteria(element);
 	}
 
-	inputs.back()->signal_remove_clicked.connect(SigC::bind(SigC::slot(*this, &Gnomoradio::CriteriaCreator::remove_input), inputs.back()));
-	inputs.back()->signal_changed.connect(SigC::slot(*this, &Gnomoradio::CriteriaCreator::emit_changed_signal));
+	inputs.back()->signal_remove_clicked.connect(sigc::bind(sigc::mem_fun(*this, &Gnomoradio::CriteriaCreator::remove_input), inputs.back()));
+	inputs.back()->signal_changed.connect(sigc::mem_fun(*this, &Gnomoradio::CriteriaCreator::emit_changed_signal));
 	vbox.pack_start(*inputs.back(), PACK_SHRINK, 3);
 
 	signal_changed.emit();
