@@ -22,16 +22,15 @@
 #include "playlist-druid.h"
 #include "browser-link.h"
 #include "song-info.h"
-#include <gconfmm.h>
+#include "conf.h"
 #include <iostream>
 #include <sstream>
 #include "config.h"
 
 using namespace std;
-using namespace SigC;
+using namespace sigc;
 using namespace Glib;
 using namespace Gtk;
-using namespace Gnome;
 using namespace Wraporadio;
 using namespace Gnomoradio;
 
@@ -43,11 +42,11 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	  list(init, chooser_store.store->children().begin()->get_value(chooser_store.song_list_col)),
 	  controls(init, &list, this),
 	  wr(init),
-	  file_findcurrentsong(_("Find Current Song")),
-	  edit_songinfo(_("Song Info...")),
-	  playlist_settings(_("Settings...")),
-	  playlist_remove(_("Remove...")),
-	  playlist_removesong(_("Remove Song")),
+	  file_findcurrentsong(_("Find _Current Song"), true),
+	  edit_songinfo(_("Song _Info..."), true),
+	  playlist_settings(_("_Settings..."), true),
+	  playlist_remove(_("Remove _Playlist..."), true),
+	  playlist_removesong(_("_Remove Song"), true),
 	  shuffle_button(_("Shuffle")),
 	  repeat_button(_("Repeat")),
 	  search_online(_("Online Search")),
@@ -55,9 +54,8 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	  about_box(0)
 {
 	int width, height;
-	Glib::RefPtr<Conf::Client> conf = Conf::Client::get_default_client();
-	width = conf->get_int("/apps/gnomoradio/main_window_width");
-	height = conf->get_int("/apps/gnomoradio/main_window_height");
+	width = Conf::get_int("main_window_width");
+	height = Conf::get_int("main_window_height");
 	if (width == 0)
 		width = 600;
 	if (height == 0)
@@ -70,7 +68,7 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	}
 
 	// playlist chooser width
-	int playlist_chooser_width = conf->get_int("/apps/gnomoradio/playlist_chooser_width");
+	int playlist_chooser_width = Conf::get_int("playlist_chooser_width");
 	if (playlist_chooser_width)
 		hpaned.set_position(playlist_chooser_width);
 
@@ -80,8 +78,8 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	int col_num = 0;
 
 	for (std::list<TreeViewColumn*>::iterator i = cols.begin(); i != cols.end(); ++i) {
-		ss << "/apps/gnomoradio/col_width_" << col_num;
-		int col_width = conf->get_int(ss.str());
+		ss << "col_width_" << col_num;
+		int col_width = Conf::get_int(ss.str());
 	
 		if (col_width <= 0)
 			col_width = 200;
@@ -100,10 +98,10 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	MenuBar *menu_bar = manage(new MenuBar);
 
 	/* File  */
-	MenuItem *file          = manage(new MenuItem(_("File")));
+	MenuItem *file          = manage(new MenuItem(_("_File"), true));
 	Menu *file_menu         = manage(new Menu);
-	MenuItem *file_add_uri  = manage(new MenuItem(_("Add URI...")));
-	MenuItem *file_exit     = manage(new MenuItem(_("Exit")));
+	MenuItem *file_add_uri  = manage(new MenuItem(_("Add _URI..."), true));
+	MenuItem *file_exit     = manage(new MenuItem(_("E_xit"), true));
 	
 	file_menu->append(*file_add_uri);
 	file_menu->append(*manage(new SeparatorMenuItem));
@@ -112,37 +110,44 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	file_menu->append(*file_exit);
 	file->set_submenu(*file_menu);
 
-	file_add_uri->signal_activate().connect(slot(*this, &MainWindow::on_file_add_uri_activate));
-	file_findcurrentsong.signal_activate().connect(slot(*this, &MainWindow::find_current_song));
+	file_add_uri->signal_activate().connect(mem_fun(*this, &MainWindow::on_file_add_uri_activate));
+	file_findcurrentsong.signal_activate().connect(mem_fun(*this, &MainWindow::find_current_song));
 	file_findcurrentsong.set_sensitive(false);
-	file_exit->signal_activate().connect(slot(*this, &MainWindow::on_file_exit_activate));
+	file_exit->signal_activate().connect(mem_fun(*this, &MainWindow::on_file_exit_activate));
 
 	/* Playlist */
-	MenuItem *playlist        = manage(new MenuItem(_("Playlist")));
+	MenuItem *playlist        = manage(new MenuItem(_("_Playlist"), true));
 	Menu *playlist_menu       = manage(new Menu);
 
-	Gtk::MenuItem *new_list = manage(new MenuItem(_("New...")));
-	new_list->signal_activate().connect(slot(*this, &MainWindow::create_playlist));
+	Gtk::MenuItem *new_list = manage(new MenuItem(_("_New Playlist..."), true));
+	new_list->signal_activate().connect(mem_fun(*this, &MainWindow::create_playlist));
+	Gtk::MenuItem *import_list = manage(new MenuItem(_("_Import Playlist..."), true));
+	import_list->signal_activate().connect(mem_fun(*this, &MainWindow::import_playlist));
+	Gtk::MenuItem *export_list = manage(new MenuItem(_("_Export Playlist..."), true));
+	export_list->signal_activate().connect(mem_fun(*this, &MainWindow::export_playlist));
 
 	playlist_menu->append(*new_list);
+	playlist_menu->append(*import_list);
+	playlist_menu->append(*export_list);
+	playlist_menu->append(*manage(new SeparatorMenuItem()));
 	playlist_menu->append(playlist_settings);
 	playlist_menu->append(playlist_removesong);
 	playlist_menu->append(playlist_remove);
 	playlist->set_submenu(*playlist_menu);
 
-	playlist_settings.signal_activate().connect(slot(*this, &MainWindow::on_playlist_settings_activate));
+	playlist_settings.signal_activate().connect(mem_fun(*this, &MainWindow::on_playlist_settings_activate));
 	playlist_settings.set_sensitive(false);
 
-	playlist_remove.signal_activate().connect(slot(*this, &MainWindow::on_playlist_remove_activate));
+	playlist_remove.signal_activate().connect(mem_fun(*this, &MainWindow::on_playlist_remove_activate));
 	playlist_remove.set_sensitive(false);
 
-	playlist_removesong.signal_activate().connect(slot(*this, &MainWindow::on_playlist_removesong_activate));
+	playlist_removesong.signal_activate().connect(mem_fun(*this, &MainWindow::on_playlist_removesong_activate));
 	playlist_removesong.set_sensitive(false);
 
 	/* Edit  */
-	MenuItem *edit             = manage(new MenuItem(_("Edit")));
+	MenuItem *edit             = manage(new MenuItem(_("_Edit"), true));
 	Menu *edit_menu            = manage(new Menu);
-	MenuItem *edit_preferences = manage(new MenuItem(_("Preferences...")));
+	MenuItem *edit_preferences = manage(new MenuItem(_("_Preferences..."), true));
 	SeparatorMenuItem *sep2    = manage(new SeparatorMenuItem());
 
 	edit_menu->append(edit_songinfo);
@@ -151,19 +156,19 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	edit->set_submenu(*edit_menu);
 
 	edit_songinfo.set_sensitive(false);
-	edit_songinfo.signal_activate().connect(slot(*this, &MainWindow::on_edit_song_info_activate));
+	edit_songinfo.signal_activate().connect(mem_fun(*this, &MainWindow::on_edit_song_info_activate));
 
-	edit_preferences->signal_activate().connect(slot(*this, &MainWindow::on_edit_preferences_activate));
+	edit_preferences->signal_activate().connect(mem_fun(*this, &MainWindow::on_edit_preferences_activate));
 
 	/* Help  */
-	MenuItem *help       = manage(new MenuItem(_("Help")));
+	MenuItem *help       = manage(new MenuItem(_("_Help"), true));
 	Menu *help_menu      = manage(new Menu);
-	MenuItem *help_about = manage(new MenuItem(_("About...")));
+	MenuItem *help_about = manage(new MenuItem(_("_About..."), true));
 
 	help_menu->append(*help_about);
 	help->set_submenu(*help_menu);
 
-	help_about->signal_activate().connect(slot(*this, &MainWindow::on_help_about_activate));
+	help_about->signal_activate().connect(mem_fun(*this, &MainWindow::on_help_about_activate));
 
 	/* pack menus */
 	menu_bar->append(*file);
@@ -181,22 +186,23 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	left.pack_start(scrolled_window);
 	left.pack_start(list_controls, PACK_SHRINK);
 
-	shuffle_button.signal_clicked().connect(slot(*this, &MainWindow::on_shuffle_clicked));
-	repeat_button.signal_clicked().connect(slot(*this, &MainWindow::on_repeat_clicked));
+	shuffle_button.signal_clicked().connect(mem_fun(*this, &MainWindow::on_shuffle_clicked));
+	repeat_button.signal_clicked().connect(mem_fun(*this, &MainWindow::on_repeat_clicked));
 	list_controls.set_homogeneous(true);
 	list_controls.pack_start(shuffle_button, PACK_EXPAND_WIDGET);
 	list_controls.pack_start(repeat_button, PACK_EXPAND_WIDGET);
 
-	list.get_tree_view()->get_selection()->signal_changed().connect(slot(*this, &MainWindow::set_edit_song_info_sensitivity));
+	list.get_tree_view()->get_selection()->signal_changed().connect(mem_fun(*this, &MainWindow::set_edit_song_info_sensitivity));
 
-	list.signal_different_list.connect(slot(*this, &MainWindow::different_list_viewed));
+	list.signal_different_list.connect(mem_fun(*this, &MainWindow::different_list_viewed));
 	different_list_viewed(list.current_list());
 
 	Label *search_label = manage(new Label(_("Search: ")));
 
-	search.signal_changed().connect(slot(*this, &MainWindow::search_changed));
-	search.signal_activate().connect(slot(*this, &MainWindow::search_activate));
-	search_online.signal_clicked().connect(slot(*this, &MainWindow::search_activate));
+	search.signal_changed().connect(mem_fun(*this, &MainWindow::search_changed));
+	search.signal_activate().connect(mem_fun(*this, &MainWindow::search_activate));
+	search_online.signal_clicked().connect(mem_fun(*this, &MainWindow::search_activate));
+	search_online.set_sensitive(false);
 
 	Gtk::HBox *search_hbox = manage(new HBox(false, 2));
 	search_hbox->pack_start(*search_label, PACK_SHRINK);
@@ -214,43 +220,44 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	chooser.append_column(_("Icon"), chooser_store.icon_col);
 	chooser.append_column_editable(_("List"), chooser_store.name_col);
 
-	chooser.signal_button_press_event().connect(slot(*this, &MainWindow::on_chooser_clicked), false);
+	chooser.signal_button_press_event().connect(mem_fun(*this, &MainWindow::on_chooser_clicked), false);
 
 	Gtk::CellRendererText *renderer = static_cast<Gtk::CellRendererText *>(chooser.get_column_cell_renderer(1));
 
-	renderer->signal_edited().connect(slot(*this, &MainWindow::on_playlist_rename));
+	renderer->signal_edited().connect(mem_fun(*this, &MainWindow::on_playlist_rename));
 
 	chooser.get_selection()->signal_changed().
-		connect(slot(*this, &MainWindow::on_chooser_change));
+		connect(mem_fun(*this, &MainWindow::on_chooser_change));
 	std::vector<TargetEntry> t;
 	t.push_back(Gnomoradio::MainWindow::song_target);
 	chooser.enable_model_drag_dest(t, Gdk::ACTION_COPY);
-	chooser.signal_drag_data_received().connect(slot(*this, &MainWindow::on_chooser_drag_data_received));
+	chooser.signal_drag_data_received().connect(mem_fun(*this, &MainWindow::on_chooser_drag_data_received));
 
-	wr->player()->signal_state_changed.connect(slot(*this, &MainWindow::on_state_changed));
+	wr->player()->signal_state_changed.connect(mem_fun(*this, &MainWindow::on_state_changed));
+
+	chooser.get_selection()->select(store->store->children().begin());
 }
 
 Gnomoradio::MainWindow::~MainWindow ()
 {
 	int w, h;
-	Glib::RefPtr<Conf::Client> conf = Conf::Client::get_default_client();
 	get_size(w, h);
 
-	conf->set("/apps/gnomoradio/main_window_width", w);
-	conf->set("/apps/gnomoradio/main_window_height", h);
+	Conf::set("main_window_width", w);
+	Conf::set("main_window_height", h);
 
 	std::stringstream ss;
 	std::list<TreeViewColumn*> cols = list.get_tree_view()->get_columns();
 	int col_num = 0;
 
 	for (std::list<TreeViewColumn*>::iterator i = cols.begin(); i != cols.end(); ++i) {
-		ss << "/apps/gnomoradio/col_width_" << col_num;
-		conf->set(ss.str(), (*i)->get_width());
+		ss << "col_width_" << col_num;
+		Conf::set(ss.str(), (*i)->get_width());
 		col_num++;
 		ss.str("");
 	}
 
-	conf->set("/apps/gnomoradio/playlist_chooser_width",
+	Conf::set("playlist_chooser_width",
 		  hpaned.get_position());
 }
 
@@ -284,33 +291,31 @@ bool Gnomoradio::MainWindow::on_chooser_clicked (GdkEventButton *event)
 		Gtk::MenuItem *settings = manage(new MenuItem(_("Settings...")));
 		Gtk::MenuItem *remove = manage(new MenuItem(_("Remove...")));
 
-		settings->signal_activate().connect(bind(slot(*this, &MainWindow::on_right_click_songlist_settings_activate), songlist));
+		settings->signal_activate().connect(bind(mem_fun(*this, &MainWindow::on_right_click_songlist_settings_activate), songlist));
 		menu->append(*settings);
 
-		remove->signal_activate().connect(bind(slot(*this, &MainWindow::remove_playlist), songlist));
+		remove->signal_activate().connect(bind(mem_fun(*this, &MainWindow::remove_playlist), songlist));
 		menu->append(*remove);
 
 		remove->set_sensitive(songlist.destroyable());
 
 		menu->show_all();
 		menu->popup(event->button, event->time);
-
-		return true;
 	}
 
-	return false; // I have no idea what this does either
+	return false; // keep it selected
 }
 
 void Gnomoradio::MainWindow::search_changed ()
 {
 	if (search.get_text().size() == 0) {
-		if (chooser.get_selection()->get_selected())
-			list.set(chooser.get_selection()->get_selected()->get_value(store->song_list_col));
-		else
-			list.set(store->store->children().begin()->get_value(store->song_list_col));
+		if (!chooser.get_selection()->get_selected())
+			chooser.get_selection()->select(store->store->children().begin());
+		list.set(chooser.get_selection()->get_selected()->get_value(store->song_list_col));
 
 		playlist_settings.set_sensitive(true);
 		playlist_remove.set_sensitive(list.current_list().destroyable());
+		search_online.set_sensitive(false);
 		return;
 	}
 
@@ -346,12 +351,36 @@ void Gnomoradio::MainWindow::search_changed ()
 	list.set(*search_list);
 	playlist_settings.set_sensitive(false);
 	playlist_remove.set_sensitive(false);
+	search_online.set_sensitive(true);
 }
 
 void Gnomoradio::MainWindow::search_activate ()
 {
 	if (&*search_list)
-		search_list->search_online();
+		search_list->search_online(search.get_text());
+	search_online.set_sensitive(false);
+}
+
+void Gnomoradio::MainWindow::import_playlist ()
+{
+	FileFilter filter;
+	filter.set_name(_("XSPF Playlists"));
+	filter.add_mime_type("application/xspf+xml");
+	filter.add_pattern("*.xspf");
+
+	FileChooserDialog fc(*this, _("Import Playlist..."));
+	fc.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+	fc.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_OK);
+	fc.set_filter(filter);
+	int result = fc.run();
+
+	if (result == Gtk::RESPONSE_OK)
+		XSPF::import_list(filename_to_utf8(fc.get_filename()));
+}
+
+void Gnomoradio::MainWindow::export_playlist ()
+{
+
 }
 
 void Gnomoradio::MainWindow::create_playlist ()
@@ -367,8 +396,9 @@ void Gnomoradio::MainWindow::remove_playlist (Wraporadio::SongList songlist)
 	
 	dialog.set_resizable(false);
 	dialog.set_border_width(5);
-	dialog.add_button(_("Remove"), 1);
-	dialog.add_button(_("Cancel"), 0);
+	dialog.add_button(Stock::CANCEL, 0);
+	dialog.add_button(Stock::REMOVE, 1);
+	dialog.set_default_response(1);
 	
 	Label *question = manage(new Label(_("Really remove playlist: ") + playlist_title + _("?")));
 	dialog.get_vbox()->pack_start(*question, PACK_SHRINK, 8);
@@ -377,10 +407,8 @@ void Gnomoradio::MainWindow::remove_playlist (Wraporadio::SongList songlist)
 	int response_yes = dialog.run();
 	
 	if (response_yes) {
-		list.set(store->store->children().begin()->get_value(store->song_list_col));
-		playlist_settings.set_sensitive(true);
-		playlist_remove.set_sensitive(list.current_list().destroyable());
 		songlist.destroy();
+		chooser.get_selection()->select(store->store->children().begin());
 	}
 }
 
@@ -406,7 +434,8 @@ void Gnomoradio::MainWindow::on_right_click_songlist_settings_activate (Wraporad
 
 void Gnomoradio::MainWindow::on_playlist_rename (const Glib::ustring& path, const Glib::ustring& new_text)
 {
-	chooser.get_selection()->get_selected()->get_value(store->song_list_col).set_name(new_text);
+	if (chooser.get_selection()->get_selected())
+		chooser.get_selection()->get_selected()->get_value(store->song_list_col).set_name(new_text);
 }
 
 void Gnomoradio::MainWindow::on_chooser_change ()
@@ -450,21 +479,21 @@ void Gnomoradio::MainWindow::on_file_add_uri_activate ()
 		add_uri_box->set_resizable(false);
 
 		Label *URI = manage(new Label(_("URI: ")));
-		Button *activate_button = manage(new Button(_("Add")));
-		Button *close_button = manage(new Button(_("Close")));
+		Button *activate_button = manage(new Button(Stock::ADD));
+		Button *close_button = manage(new Button(Stock::CLOSE));
 		HBox *hbox = manage(new HBox(false, 8));
 		HBox *hbox2 = manage(new HBox(false, 8));
 		VBox *vbox = manage(new VBox(false, 8));
 
-		uri_entry.signal_activate().connect(slot(*this, &MainWindow::on_uri_entry_activate));
-		activate_button->signal_clicked().connect(slot(*this, &MainWindow::on_uri_entry_activate));
-		close_button->signal_clicked().connect(slot(*this, &MainWindow::on_uri_close_activate));
+		uri_entry.signal_activate().connect(mem_fun(*this, &MainWindow::on_uri_entry_activate));
+		activate_button->signal_clicked().connect(mem_fun(*this, &MainWindow::on_uri_entry_activate));
+		close_button->signal_clicked().connect(mem_fun(*this, &MainWindow::on_uri_close_activate));
 
 		hbox->pack_start(*URI, PACK_SHRINK);
 		hbox->pack_start(uri_entry, PACK_SHRINK);
 
-		hbox2->pack_start(*activate_button);
 		hbox2->pack_start(*close_button);
+		hbox2->pack_start(*activate_button);
 
 		vbox->pack_start(*hbox);
 		vbox->pack_start(*hbox2);
@@ -543,21 +572,21 @@ void Gnomoradio::MainWindow::on_help_about_activate ()
 		about_box->add(*table);
 
 		Label *title = manage(new Label("Gnomoradio " VERSION));
-		Label *jim  = manage(new Label("Jim Garrison <garrison@case.edu>"));
-		Label *matt  = manage(new Label("Matt Gerginski <mattgerg@users.sourceforge.net>"));
+		Label *jim  = manage(new Label("Jim Garrison <garrison@gnomoradio.org>"));
+		Label *matt  = manage(new Label("Matt Gerginski <mattgerg@gnomoradio.org>"));
 
 		Label *description = manage(new Label(_("Gnomoradio is a music playing robot with a mind of its own")));
 
-		Button *web_link    = manage(new Button("http://gnomoradio.org/"));
-		web_link->signal_clicked().connect(bind(slot(&BrowserLink::open_url), "http://gnomoradio.org/"));
+		Button *web_link   = manage(new Button("http://gnomoradio.org/"));
+		web_link->signal_clicked().connect(bind(sigc::ptr_fun(&BrowserLink::open_url), "http://gnomoradio.org/"));
 
 		Label *copyright   = manage(new Label(_("Copyright (c) 2003-2004 under the terms of the")));
 
 		Label *gpl         = manage(new Label(_("GNU General Public License")));
 
-		Button *close = manage(new Button(_("Close")));
+		Button *close = manage(new Button(Stock::CLOSE));
 
-		close->signal_clicked().connect(slot(*this, &MainWindow::on_about_box_close));
+		close->signal_clicked().connect(mem_fun(*this, &MainWindow::on_about_box_close));
 
 		VBox *license_vbox = manage(new VBox());
 
@@ -605,21 +634,18 @@ void Gnomoradio::MainWindow::on_about_box_close ()
 	}
 }
 
-void Gnomoradio::MainWindow::on_chooser_drag_data_received (const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, GtkSelectionData* selection_data, guint info, guint time)
+void Gnomoradio::MainWindow::on_chooser_drag_data_received (const Glib::RefPtr<Gdk::DragContext> &context, int x, int y, const Gtk::SelectionData &selection_data, guint info, guint time)
 {
-	if (selection_data->format != 8)
+	ustring url(selection_data.get_text());
+	if (url == "")
 		return;
 
-	char *url = g_strndup((char*) selection_data->data, selection_data->length);
-
 	int cell_x, cell_y;
 	TreeModel::Path path;
 	TreeViewColumn *column;
 	chooser.get_path_at_pos(x, y, path, column, cell_x, cell_y);
 
 	store->store->get_iter(path)->get_value(store->song_list_col).push_back(Song(url));
-
-	g_free(url);
 }
 
 void Gnomoradio::MainWindow::on_state_changed ()
