@@ -26,7 +26,7 @@
 #include "control-previous.xpm"
 
 using namespace std;
-using namespace SigC;
+using namespace sigc;
 using namespace Gtk;
 using namespace Gdk;
 using namespace Wraporadio;
@@ -63,17 +63,17 @@ PlayerControls::PlayerControls (Wraporadio::Init *wrap,
 	stop_img.show();
 	pause_img.show();
 
-	prev.signal_clicked().connect(slot(*this, &PlayerControls::on_prev_clicked));
-	state.signal_clicked().connect(slot(*this, &PlayerControls::on_state_clicked));
-	next.signal_clicked().connect(slot(*this, &PlayerControls::on_next_clicked));
+	prev.signal_clicked().connect(mem_fun(*this, &PlayerControls::on_prev_clicked));
+	state.signal_clicked().connect(mem_fun(*this, &PlayerControls::on_state_clicked));
+	next.signal_clicked().connect(mem_fun(*this, &PlayerControls::on_next_clicked));
 
 	prev.set_sensitive(false);
 	next.set_sensitive(false);
 
 	position.signal_button_press_event()
-		.connect(slot(*this, &PlayerControls::on_position_click_event), false);
+		.connect(mem_fun(*this, &PlayerControls::on_position_click_event), false);
 	position.signal_button_release_event()
-		.connect(slot(*this, &PlayerControls::on_position_click_event), false);
+		.connect(mem_fun(*this, &PlayerControls::on_position_click_event), false);
 
 	position.set_draw_value(false);
 	position.set_sensitive(false);
@@ -85,7 +85,7 @@ PlayerControls::PlayerControls (Wraporadio::Init *wrap,
 	song_info_event_box->add(song_info);
 	song_info_event_box->set_events(Gdk::BUTTON_PRESS_MASK);
 	song_info_event_box->signal_button_press_event()
-		.connect(slot(*this, &PlayerControls::on_button_press_event));
+		.connect(mem_fun(*this, &PlayerControls::on_button_press_event));
 
 	// packing
 	HBox *button_hbox = manage(new HBox(true, 4));
@@ -112,10 +112,10 @@ PlayerControls::PlayerControls (Wraporadio::Init *wrap,
 	pack_start(*pos_song_info_vbox, PACK_EXPAND_WIDGET, 8);
 	show_all();
 
-	pl_view->signal_different_list.connect(slot(*this, &PlayerControls::on_viewed_playlist_changed));
-	wr->player()->signal_state_changed.connect(slot(*this, &PlayerControls::on_state_changed));
-	wr->player()->signal_song_changed.connect(slot(*this, &PlayerControls::on_song_changed));
-	wr->player()->signal_state_changed.connect(slot(*this, &PlayerControls::on_song_changed));
+	pl_view->signal_different_list.connect(mem_fun(*this, &PlayerControls::on_viewed_playlist_changed));
+	wr->player()->signal_state_changed.connect(mem_fun(*this, &PlayerControls::on_state_changed));
+	wr->player()->signal_song_changed.connect(mem_fun(*this, &PlayerControls::on_song_changed));
+	wr->player()->signal_state_changed.connect(mem_fun(*this, &PlayerControls::on_song_changed));
 }
 
 void Gnomoradio::PlayerControls::on_prev_clicked ()
@@ -147,7 +147,7 @@ void Gnomoradio::PlayerControls::on_song_changed ()
 		unsigned int len = wr->player()->get_song()->get_length();
 		position.set_range(0, len ? len : 1);
 		song_position_changed_connection = wr->player()->get_song()->signal_position_changed
-			.connect(slot(*this, &PlayerControls::on_song_position_changed));
+			.connect(mem_fun(*this, &PlayerControls::on_song_position_changed));
 
 		Glib::ustring artist = wr->player()->get_song()->get_info("artist");
 		Glib::ustring title  = wr->player()->get_song()->get_info("title");
@@ -216,7 +216,7 @@ bool Gnomoradio::PlayerControls::on_position_click_event (GdkEventButton *event)
 	if (event->button == 1) {
 		if (event->type == GDK_BUTTON_PRESS) {
 			user_changing_position = true; 
-			position_timer_connection = position.signal_value_changed().connect(SigC::slot(*this, &PlayerControls::sync_timer_to_position_change));
+			position_timer_connection = position.signal_value_changed().connect(sigc::mem_fun(*this, &PlayerControls::sync_timer_to_position_change));
 		} else if (event->type == GDK_BUTTON_RELEASE) {
 			user_changing_position = false;
 			position_timer_connection.disconnect();
