@@ -68,7 +68,7 @@ namespace Gnomoradio
 		
 		bool user_changing_position;
 
-		SigC::Connection song_position_changed_connection, position_timer_connection;
+		sigc::connection song_position_changed_connection, position_timer_connection;
 	};
 }
 
