@@ -23,11 +23,11 @@ using namespace Glib;
 using namespace std;
 
 Gnomoradio::SongPaths::SongPaths ()
-	: remove_path_button(_("Remove")),
-	  add_path_button(_("Add"))
+	: remove_path_button(Gtk::Stock::REMOVE),
+	  add_path_button(Gtk::Stock::ADD)
 {
-	add_path_button.signal_clicked().connect(SigC::slot(*this, &Gnomoradio::SongPaths::add_path_button_clicked));
-	remove_path_button.signal_clicked().connect(SigC::slot(*this, &Gnomoradio::SongPaths::remove_path_button_clicked));
+	add_path_button.signal_clicked().connect(sigc::mem_fun(*this, &Gnomoradio::SongPaths::add_path_button_clicked));
+	remove_path_button.signal_clicked().connect(sigc::mem_fun(*this, &Gnomoradio::SongPaths::remove_path_button_clicked));
 
 	resize(2, 2);
 	set_homogeneous(false);
@@ -55,15 +55,15 @@ Gnomoradio::SongPaths::SongPaths ()
 
 void Gnomoradio::SongPaths::add_path_button_clicked ()
 {
-	FileSelection dialog(_("Select Directory"));
+	FileChooserDialog dialog(_("Select Directory"), Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER);
+	dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+	dialog.add_button(Gtk::Stock::ADD, Gtk::RESPONSE_OK);
  
 	Widget *toplevel = song_path_treeview.get_toplevel();
 
 	if (toplevel->get_flags() & TOPLEVEL)
 		dialog.set_transient_for(static_cast<Gtk::Window&>(*toplevel));
 
-	dialog.get_file_list()->get_parent()->hide(); // disable selecting files
-
 	int response = dialog.run();
 
 	if (response == RESPONSE_OK) {
