@@ -42,7 +42,7 @@ Gnomoradio::SongRater::SongRater (int value) :
 {
 	update_rater();
 
-	adj.signal_value_changed().connect(SigC::slot(*this, &Gnomoradio::SongRater::on_adj_value_changed));
+	adj.signal_value_changed().connect(sigc::mem_fun(*this, &Gnomoradio::SongRater::on_adj_value_changed));
 }
 
 Gnomoradio::SongRater::SongRater (int value, int lower, int upper) :
@@ -80,7 +80,7 @@ Gnomoradio::SongRater::SongRater (int value, int lower, int upper) :
 
 		pack_start(*event_boxes[i], PACK_EXPAND_PADDING, 2);
 
-		event_boxes[i]->signal_button_press_event().connect(SigC::bind<int>(SigC::slot(*this, &Gnomoradio::SongRater::on_image_clicked), i));
+		event_boxes[i]->signal_button_press_event().connect(sigc::bind<int>(sigc::mem_fun(*this, &Gnomoradio::SongRater::on_image_clicked), i));
 	}
 
 	/* assign neutral_pixbuf to image representing "0" rating */
@@ -88,12 +88,12 @@ Gnomoradio::SongRater::SongRater (int value, int lower, int upper) :
 
 	pack_start(plus, PACK_SHRINK);
 
-	minus.signal_clicked().connect(SigC::slot(*this, &Gnomoradio::SongRater::on_minus_clicked));
-	plus.signal_clicked().connect(SigC::slot(*this, &Gnomoradio::SongRater::on_plus_clicked));
+	minus.signal_clicked().connect(sigc::mem_fun(*this, &Gnomoradio::SongRater::on_minus_clicked));
+	plus.signal_clicked().connect(sigc::mem_fun(*this, &Gnomoradio::SongRater::on_plus_clicked));
 
 	update_rater();
 
-	adj.signal_value_changed().connect(SigC::slot(*this, &Gnomoradio::SongRater::on_adj_value_changed));
+	adj.signal_value_changed().connect(sigc::mem_fun(*this, &Gnomoradio::SongRater::on_adj_value_changed));
 }
 
 Gnomoradio::SongRater::~SongRater ()
