@@ -25,7 +25,7 @@
 
 namespace Rainbow
 {
-	class Alarm : public SigC::Object
+	class Alarm : public sigc::trackable
 	{
 	public:
 		Alarm ();
@@ -38,12 +38,12 @@ namespace Rainbow
 		void reset ()
 			{ t = 0; }
 
-		SigC::Signal0<void> &signal_alarm () { return signal; }
+		sigc::signal<void> &signal_alarm () { return signal; }
 
 	private:
 		bool timeout_handler ();
 
-		SigC::Signal0<void> signal;
+		sigc::signal<void> signal;
 		time_t t;
 	};
 }
