@@ -35,20 +35,20 @@ extern "C" {
 
 namespace Rainbow
 {
-	class Checksum : public SigC::Object
+	class Checksum : public sigc::trackable
 	{
 	public:
-		static void verify (const SigC::Slot2<void,bool,Resource*> &slot,
+		static void verify (const sigc::slot<void,bool,Resource*> &mem_fun,
 				    Resource *resource);
 
 	private:
-		Checksum (const SigC::Slot2<void,bool,Resource*> &slot,
+		Checksum (const sigc::slot<void,bool,Resource*> &mem_fun,
 			  Resource *r);
 		void verify_thread ();
 		void verify_do ();
 		void dispatch ();
 		
-		SigC::Signal2<void,bool,Resource*> signal;
+		sigc::signal<void,bool,Resource*> signal;
 		Glib::Dispatcher dispatcher;
 		bool success;
 		Resource *resource;
@@ -56,19 +56,19 @@ namespace Rainbow
 		std::vector<guint8> checksum;
 	};
 
-	class HubConnector : public SigC::Object
+	class HubConnector : public sigc::trackable
 	{
 	public:
-		static void connect (const SigC::Slot1<void,int> &slot,
+		static void connect (const sigc::slot<void,int> &mem_fun,
 				     const Glib::ustring &hub_server);
 
 	private:
-		HubConnector (const SigC::Slot1<void,int> &slot,
+		HubConnector (const sigc::slot<void,int> &mem_fun,
 			      const Glib::ustring &hub_server);
 		void thread ();
 		void dispatch ();
 
-		SigC::Signal1<void,int> signal;
+		sigc::signal<void,int> signal;
 		Glib::Dispatcher dispatcher;
 		int sock;
 		sockaddr_in hub;
@@ -77,29 +77,29 @@ namespace Rainbow
 }
 
 using namespace std;
-using namespace SigC;
+using namespace sigc;
 using namespace Glib;
 using namespace Rainbow;
 
-Rainbow::Checksum::Checksum (const SigC::Slot2<void,bool,Resource*> &slot,
+Rainbow::Checksum::Checksum (const sigc::slot<void,bool,Resource*> &mem_fun,
 			     Resource *r)
 	: resource(r),
 	  filename(r->get_filename()),
 	  checksum(r->checksum),
 	  success(false)
 {
-	signal.connect(slot);
-	dispatcher.connect(SigC::slot(*this, &Checksum::dispatch));
+	signal.connect(mem_fun);
+	dispatcher.connect(sigc::mem_fun(*this, &Checksum::dispatch));
 
 	if (!Glib::thread_supported())
 		Glib::thread_init();
-	Glib::Thread::create(SigC::slot(*this, &Checksum::verify_thread), false);
+	Glib::Thread::create(sigc::mem_fun(*this, &Checksum::verify_thread), false);
 }
 
-void Rainbow::Checksum::verify (const SigC::Slot2<void,bool,Resource*> &slot,
+void Rainbow::Checksum::verify (const sigc::slot<void,bool,Resource*> &mem_fun,
 				Resource *resource)
 {
-	new Checksum(slot, resource);
+	new Checksum(mem_fun, resource);
 }
 
 void Rainbow::Checksum::verify_thread ()
@@ -154,19 +154,19 @@ void Rainbow::Checksum::dispatch ()
 	delete this;
 }
 
-void Rainbow::HubConnector::connect (const SigC::Slot1<void,int> &slot,
+void Rainbow::HubConnector::connect (const sigc::slot<void,int> &mem_fun,
 				     const Glib::ustring &hub_server)
 {
-	new HubConnector(slot, hub_server);
+	new HubConnector(mem_fun, hub_server);
 }
 
-Rainbow::HubConnector::HubConnector (const SigC::Slot1<void,int> &slot,
+Rainbow::HubConnector::HubConnector (const sigc::slot<void,int> &mem_fun,
 				     const Glib::ustring &hub_server)
 	: server(hub_server),
 	  sock(0)
 {
-	signal.connect(slot);
-	dispatcher.connect(SigC::slot(*this, &HubConnector::dispatch));
+	signal.connect(mem_fun);
+	dispatcher.connect(sigc::mem_fun(*this, &HubConnector::dispatch));
 
 	struct hostent *host = gethostbyname(hub_server.c_str());
 	if (!host) {
@@ -184,7 +184,7 @@ Rainbow::HubConnector::HubConnector (const SigC::Slot1<void,int> &slot,
 		
 		if (!Glib::thread_supported())
 			Glib::thread_init();
-		Glib::Thread::create(SigC::slot(*this, &HubConnector::thread), false);
+		Glib::Thread::create(sigc::mem_fun(*this, &HubConnector::thread), false);
 	} else {
 		signal(sock);
 		delete this;
@@ -248,7 +248,7 @@ void Rainbow::HubClient::parse_resource (xmlpp::Element *xml, ref_ptr<RdfResourc
 					Glib::ustring absolute = RdfResource::absolute_uri(resource_link->get_value(),
 										    rdf->get_base_uri());
 					License::get_and_do(absolute,
-							    bind(slot(*this, &HubClient::license_obtained_callback), r),
+							    bind(mem_fun(*this, &HubClient::license_obtained_callback), r),
 							    rdf->get_secondary_info(absolute));
 				}
 			} else if (el->get_name() == "checksum") {
@@ -291,10 +291,10 @@ Rainbow::HubClient::HubClient (const Glib::ustring &hub)
 	  cache_size(50),
 	  total_allocated_size(0)
 {
-	alarm.signal_alarm().connect(slot(*this, &HubClient::connect));
+	alarm.signal_alarm().connect(mem_fun(*this, &HubClient::connect));
 
 	load_database();
-	save_alarm.signal_alarm().connect(slot(*this, &HubClient::on_save_alarm));
+	save_alarm.signal_alarm().connect(mem_fun(*this, &HubClient::on_save_alarm));
 	save_alarm.set_relative(save_alarm_interval);
 
 	// FIXME: we could wait until connected to the hub to start http services
@@ -398,7 +398,7 @@ void Rainbow::HubClient::connect ()
 		// connection is already/still established
 		alarm.set_relative(reconnect_interval);
 	} else {
-		HubConnector::connect(slot(*this, &HubClient::on_connect), hub_host);
+		HubConnector::connect(mem_fun(*this, &HubClient::on_connect), hub_host);
 	}
 }
 
@@ -450,7 +450,7 @@ ref_ptr<Resource> Rainbow::HubClient::create (const Glib::ustring &url)
 		db.insert(make_pair(url, r));
 
 		if (r->has_rdf())
-			RdfResource::get_and_do(url, bind(slot(*this, &HubClient::parse_resource), &*r));
+			RdfResource::get_and_do(url, bind(mem_fun(*this, &HubClient::parse_resource), &*r));
 		else {
 			r->available_locations.push_back(url);
 			r->obtained_info = true;
@@ -565,7 +565,9 @@ void Rainbow::HubClient::query_hub (Resource *r)
 				} else {
 					// add to array
 					try {
-						r->mirrors.push_back(Glib::ustring(line));
+						Glib::ustring l(line);
+						if (l.validate())
+							r->mirrors.push_back(l);
 					} catch (...) {
 					}
 					--lines_remaining;
@@ -597,8 +599,8 @@ void Rainbow::HubClient::start_download (Resource *r)
 			return;
 		}
 		r->dl->get(r->get_url().substr(6), r->get_filename());
-		r->dl->signal_request_done.connect(bind(slot(*this, &HubClient::file_download_done_callback), r));
-		r->dl->signal_download_percent.connect(bind(slot(*this, &HubClient::file_download_percent_callback), r));
+		r->dl->signal_request_done.connect(bind(mem_fun(*this, &HubClient::file_download_done_callback), r));
+		r->dl->signal_download_percent.connect(bind(mem_fun(*this, &HubClient::file_download_percent_callback), r));
 	} else if (r->available_locations.size() > r->available_locations_cursor) {
 		Glib::ustring remote_host, remote_file;
 		unsigned short remote_port;
@@ -609,8 +611,8 @@ void Rainbow::HubClient::start_download (Resource *r)
 		}
 		r->dl.reset(new HttpClient(remote_host, remote_port, false));
 		r->dl->get(remote_file, r->get_filename());
-		r->dl->signal_request_done.connect(bind(slot(*this, &HubClient::file_download_done_callback), r));
-		r->dl->signal_download_percent.connect(bind(slot(*this, &HubClient::file_download_percent_callback), r));
+		r->dl->signal_request_done.connect(bind(mem_fun(*this, &HubClient::file_download_done_callback), r));
+		r->dl->signal_download_percent.connect(bind(mem_fun(*this, &HubClient::file_download_percent_callback), r));
 	} else {
 		// not available anywhere now
 		logmsg << "HubClient: Resource not available currently: " << r->get_url() << endl;
@@ -651,7 +653,7 @@ void Rainbow::HubClient::file_download_done_callback (bool success, Resource *r)
 	if (success) {
 		// verify checksum
 		if (r->checksum.size() != 0)
-			Checksum::verify(slot(*this, &HubClient::verify_checksum_callback), r);
+			Checksum::verify(mem_fun(*this, &HubClient::verify_checksum_callback), r);
 		else
 			download_success(r);
 	} else
@@ -731,7 +733,7 @@ void Rainbow::HubClient::uncache_resource (Resource *r)
 
 	// fixme: this should not be necessary now, but it needs to be done at some point in case you decide to download again
 	if (r->has_rdf())
-		RdfResource::get_and_do(r->get_url(), bind(slot(*this, &HubClient::parse_resource), r));
+		RdfResource::get_and_do(r->get_url(), bind(mem_fun(*this, &HubClient::parse_resource), r));
 }
 
 // fixme: maybe size should be stored, with a boolean whether it's allocated or used
