@@ -32,7 +32,7 @@
 
 namespace Rainbow
 {
-	class Resource : public SigC::Object
+	class Resource : public sigc::trackable
 	{
 	public:
 		Resource (const Glib::ustring &url_,
@@ -66,10 +66,10 @@ namespace Rainbow
 		friend class HubClient;
 		friend class Checksum;
 
-		SigC::Signal1<void,bool> signal_found_info;
-		SigC::Signal1<void,unsigned int> signal_downloading;
-		SigC::Signal1<void,bool> signal_download_done;
-		SigC::Signal0<void> signal_file_deleted;
+		sigc::signal<void,bool> signal_found_info;
+		sigc::signal<void,unsigned int> signal_downloading;
+		sigc::signal<void,bool> signal_download_done;
+		sigc::signal<void> signal_file_deleted;
 
 	private:
 		int refcnt;
@@ -89,7 +89,7 @@ namespace Rainbow
 		bool rdf_description_exists;
 	};
 
-	class HubClient : public SigC::Object
+	class HubClient : public sigc::trackable
 	{
 	public:
 		HubClient (const Glib::ustring &hub);
@@ -113,7 +113,7 @@ namespace Rainbow
 		void set_cache_size (unsigned int megabytes);
 		unsigned int get_cache_size () const { return cache_size; }
 
-		SigC::Signal1<void,size_t> signal_must_uncache; // in kilobytes
+		sigc::signal<void,size_t> signal_must_uncache; // in kilobytes
 
 	private:
 		void prepare_resource (Resource *r);
