@@ -26,6 +26,8 @@
 #include <string>
 #include <algorithm>
 
+#include <iostream>
+
 #if USE_VORBIS
 
 using namespace std;
@@ -41,8 +43,8 @@ Roboradio::Audio::Ogg::Ogg (const ustring &file)
 		initialized = true;
 	}
 
-	done_dispatch.connect(slot(*this, &Ogg::send_done));
-	position_dispatch.connect(slot(*this, &Ogg::send_position_changed));
+	done_dispatch.connect(mem_fun(*this, &Ogg::send_done));
+	position_dispatch.connect(mem_fun(*this, &Ogg::send_position_changed));
 }
 
 Roboradio::Audio::Ogg::~Ogg ()
@@ -63,7 +65,7 @@ void Roboradio::Audio::Ogg::play ()
 
 	if (!thread_supported())
 		thread_init();
-	thread = Thread::create(SigC::slot(*this, &Ogg::thread_function), true);
+	thread = Thread::create(sigc::mem_fun(*this, &Ogg::thread_function), true);
 }
 
 void Roboradio::Audio::Ogg::stop ()
@@ -118,12 +120,15 @@ map<ustring,ustring> Roboradio::Audio::Ogg::get_info (unsigned int &length)
 			if (c) {
 				for (int i = 0; i < c->comments; ++i) {
 					try {
-						ustring comment(locale_to_utf8(string(c->user_comments[i])));
-						ustring::size_type eq = comment.find('=');
-						if (eq != ustring::npos) {
-							string key(comment.substr(0, eq));
-							transform(key.begin(), key.end(), key.begin(), ::tolower);
-							info.insert(make_pair(key, comment.substr(eq + 1)));
+						ustring comment(string(c->user_comments[i]));
+						if (comment.validate()) {
+							ustring::size_type eq = comment.find('=');
+							if (eq != ustring::npos) {
+								string key(comment.substr(0, eq));
+								// FIXME: this could be done better
+								transform(key.begin(), key.end(), key.begin(), ::tolower);
+								info.insert(make_pair(key, comment.substr(eq + 1)));
+							}
 						}
 					} catch (...) {
 					}
@@ -168,6 +173,7 @@ void Roboradio::Audio::Ogg::thread_function ()
 		_position = -1;
 		mutex.unlock();
 		done_dispatch();
+		cerr << "Audio::Ogg: file could not be opened" << endl;
 		return;
 	}
 
@@ -178,6 +184,7 @@ void Roboradio::Audio::Ogg::thread_function ()
 		_position = -1;
 		mutex.unlock();
 		done_dispatch();
+		cerr << "Audio::Ogg: file is not in ogg format" << endl;
 		return;
 	}
 
@@ -193,6 +200,8 @@ void Roboradio::Audio::Ogg::thread_function ()
 	ao_device *device = 0;
 	if (device_id >= 0)
 		device = ao_open_live(device_id, &output_fmt, 0);
+	else
+		cerr << "Audio::Ogg: libao cannot find default audio device" << endl;
 
 	if (device) {
 		int bitstream = 0;
@@ -250,7 +259,8 @@ void Roboradio::Audio::Ogg::thread_function ()
 		}
 		if (device)
 			ao_close(device);
-	}
+	} else
+		cerr << "Audio::Ogg: libao failed to open audio device" << endl;
 
 	mutex.lock();
 	bool s = _stop;
