@@ -27,7 +27,7 @@ namespace Roboradio
 }
 
 using namespace std;
-using namespace SigC;
+using namespace sigc;
 using namespace Roboradio;
 
 Roboradio::Init::Init ()
@@ -40,11 +40,14 @@ Roboradio::Init::Init ()
 	session = new State;
 	session->load_preferences();
 
-	if (session->get_rainbow_enabled())
+	if (session->get_rainbow_enabled()) {
 		rainbow = new Rainbow::Init(session->get_rainbow_hub());
-	session->signal_rainbow_enabled_changed.connect(slot(&Init::on_rainbow_enabled_changed));
-	session->signal_rainbow_hub_changed.connect(slot(&Init::on_rainbow_hub_changed));
-	session->signal_rainbow_cache_size_changed.connect(slot(&Init::on_rainbow_cache_size_changed));
+		if (session->get_rainbow_cache_size())
+			rainbow->hub().set_cache_size(session->get_rainbow_cache_size());
+	}
+	session->signal_rainbow_enabled_changed.connect(sigc::ptr_fun(&Init::on_rainbow_enabled_changed));
+	session->signal_rainbow_hub_changed.connect(sigc::ptr_fun(&Init::on_rainbow_hub_changed));
+	session->signal_rainbow_cache_size_changed.connect(sigc::ptr_fun(&Init::on_rainbow_cache_size_changed));
 
 	recommend = session->load_recommendation();
 
