@@ -1,22 +1,10 @@
 #ifndef ESD_AUDIO_H
 #define ESD_AUDIO_H
 
-#include <esd.h>
 #include <glib/gtypes.h>
 
 #define N_(string) string
 
-typedef struct {
-	gboolean use_remote;
-	char *server;
-	int port;
-	int buffer_size;
-	int prebuffer;
-}
-ESDConfig;
-
-extern ESDConfig esd_cfg;
-
 typedef enum {
 	FMT_U8, 
 	FMT_S8, 
