@@ -25,7 +25,7 @@ Roboradio::SongListLibrary::SongListLibrary ()
 	: SongListAutomatic("Local Music")
 {
 	construct();
-	signal_removed.connect(SigC::slot(*this, &SongListLibrary::on_remove));
+	signal_removed.connect(sigc::mem_fun(*this, &SongListLibrary::on_remove));
 }
 
 Roboradio::SongListLibrary::~SongListLibrary ()
