@@ -260,11 +260,11 @@ Roboradio::SongListSearch::SongListSearch (const ustring &c,
 
 	set_criteria(c);
 
-	Song::signal_global_new_song.connect(slot(*this, &SongListSearch::on_song_changed));
-	Song::signal_global_song_info_changed.connect(slot(*this, &SongListSearch::on_song_changed));
-	Song::signal_global_song_rating_changed.connect(slot(*this, &SongListSearch::on_song_changed));
-	Song::signal_global_song_length_changed.connect(slot(*this, &SongListSearch::on_song_changed));
-	Song::signal_global_song_done.connect(slot(*this, &SongListSearch::on_song_changed));
+	Song::signal_global_new_song.connect(mem_fun(*this, &SongListSearch::on_song_changed));
+	Song::signal_global_song_info_changed.connect(mem_fun(*this, &SongListSearch::on_song_changed));
+	Song::signal_global_song_rating_changed.connect(mem_fun(*this, &SongListSearch::on_song_changed));
+	Song::signal_global_song_length_changed.connect(mem_fun(*this, &SongListSearch::on_song_changed));
+	Song::signal_global_song_done.connect(mem_fun(*this, &SongListSearch::on_song_changed));
 }
 
 Roboradio::SongListSearch::~SongListSearch ()
@@ -318,7 +318,7 @@ void Roboradio::SongListSearch::search_online (const ustring &search_string)
 	online = true;
 
 	http = new HttpClient("search.gnomoradio.org");
-	http->signal_request_done.connect(slot(*this, &SongListSearch::on_online_search_done));
+	http->signal_request_done.connect(mem_fun(*this, &SongListSearch::on_online_search_done));
 	http->get("/search.php?q=" + Rainbow::HttpClient::url_encode(search_string.c_str()));
 }
 
