@@ -33,9 +33,6 @@
 #include <set>
 #include <sstream>
 
-// for libxml++ workaround
-#include <libxml/tree.h>
-
 using namespace Roboradio;
 using namespace Glib;
 using namespace std;
@@ -54,6 +51,8 @@ namespace Roboradio
 	};
 
 	map<ustring,DirectoryData> directories;
+	map<ustring,DIR*> directories_to_scan;
+	sigc::connection idle_loop_connection;
 }
 
 static inline bool str_ends_in (const char *s, const char *e)
@@ -67,9 +66,6 @@ static inline bool str_ends_in (const char *s, const char *e)
 void Roboradio::State::find_songs (const ustring &directory, unsigned short recursion_level)
 {
         DIR *dir = 0;
-        struct dirent *dirent;
-        ustring dirsep = "/";
-        const char **ext;
 
 	try {
 		dir = opendir(filename_from_utf8(directory).c_str());
@@ -80,35 +76,68 @@ void Roboradio::State::find_songs (const ustring &directory, unsigned short recu
 		// add to list of directories
 		directories.insert(make_pair(directory, DirectoryData(recursion_level))); // will not overwrite info in a map
 
-		while ((dirent = readdir(dir))) {
-			try {
-				if (dirent->d_name[0] == '.') // skip hidden files and current and parent directory
-					continue;
-				string filename_str = filename_from_utf8(directory) + dirsep + dirent->d_name;
-				ustring filename = filename_to_utf8(filename_str);
-				struct stat s;
-				if (stat(filename_str.c_str(), &s))
-					continue;
-				if (S_ISDIR(s.st_mode) && recursion_level < 20) {
-					if (directories.find(filename) == directories.end()) {
-						find_songs(filename, recursion_level + 1);
-					}
-				}
-				if (str_ends_in(dirent->d_name, ".mp3")
-				    || str_ends_in(dirent->d_name, ".ogg")) {
-					SongRef s(filename);
-					s->set_status_available(true);
-					s->set_status_ready(true);
-				}
-			} catch (...) {
-			}
-		}
-		closedir(dir);
+		if (directories_to_scan.find(directory) == directories_to_scan.end()) {
+			directories_to_scan.insert(make_pair(directory, dir));
+
+			// start the idle loop
+			if (!idle_loop_connection.connected())
+				idle_loop_connection = Glib::signal_idle().connect(sigc::mem_fun(*this, &State::find_song_step));
+		} else
+			closedir(dir);
 	} else {
 		cerr << "Could not open directory" << endl;
 	}
 }
 
+bool Roboradio::State::find_song_step ()
+{
+	map<ustring,DIR*>::iterator ds = directories_to_scan.begin();
+	if (ds == directories_to_scan.end()) {
+		// stop this idle loop
+		return false;
+	}
+	ustring directory = ds->first;
+
+	DIR *dir = ds->second;
+        struct dirent *dirent;
+        ustring dirsep = "/";
+        const char **ext;
+
+	map<ustring,DirectoryData>::iterator d = directories.find(directory);
+
+	if ((dirent = readdir(dir))
+	    && d != directories.end()) {
+		unsigned short recursion_level = d->second.recursion_level;
+
+		try {
+			if (dirent->d_name[0] == '.') // skip hidden files and current and parent directory
+				return true;
+			string filename_str = filename_from_utf8(directory) + dirsep + dirent->d_name;
+			ustring filename = filename_to_utf8(filename_str);
+			struct stat s;
+			if (stat(filename_str.c_str(), &s))
+				return true;
+			if (S_ISDIR(s.st_mode) && recursion_level < 20) {
+				if (directories.find(filename) == directories.end()) {
+					find_songs(filename, recursion_level + 1);
+				}
+			}
+			if (str_ends_in(dirent->d_name, ".mp3")
+			    || str_ends_in(dirent->d_name, ".ogg")) {
+				SongRef s(filename);
+				s->set_status_available(true);
+				s->set_status_ready(true);
+			}
+		} catch (...) {
+		}
+	} else {
+		closedir(dir);
+		directories_to_scan.erase(directory);
+	}
+
+	return true;
+}
+
 void Roboradio::State::scan_for_new_songs ()
 {
 	map<ustring,DirectoryData> d(directories);
@@ -154,7 +183,7 @@ Roboradio::State::State ()
 
 	// scan for new songs every minute
 	const int interval = 60;
-	Glib::signal_timeout().connect(SigC::slot(*this, &State::rescan_timeout_handler), 1000 * interval);
+	Glib::signal_timeout().connect(sigc::mem_fun(*this, &State::rescan_timeout_handler), 1000 * interval);
 }
 
 Roboradio::State::~State ()
@@ -254,14 +283,16 @@ void Roboradio::State::load_songs ()
 						}
 
 						SongRef s(url->get_value(), false);
-						if (audiofiles.size()) {
-							// FIXME: make local files that are rainbow files act as such
-							SongRainbow *sr = dynamic_cast<SongRainbow*>(&*s);
-							if (sr) {
-								s->set_status_available(true);
+						SongRainbow *sr = dynamic_cast<SongRainbow*>(&*s);
+						if (sr) {
+							s->set_status_available(true);
+							if (audiofiles.size()) {
+								// FIXME: make local files that are rainbow files act as such
 								sr->audiofiles = audiofiles;
 								sr->on_audiofiles_determined();
-							}
+							} else if (!sr->has_rdf()
+								   && &*Init::get_rainbow().hub().find(url->get_value()))
+								sr->create_hub_resource();
 						}
 						
 						xmlpp::Attribute *user_rating = song->get_attribute("user_rating");
@@ -350,24 +381,9 @@ void Roboradio::State::load_song_lists ()
 					       && !dynamic_cast<xmlpp::Element*>(*search_node))
 						++search_node;
 					if (search_node != sub.end()) {
-#if 0 // this will work once libxml++ 2.5 becomes stable
 						xmlpp::Document search_tree;
 						search_tree.create_root_node_by_import(*search_node);
 						new SongListSearch(search_tree.write_to_string(), name->get_value());
-#else
-						xmlDoc *search_tree = xmlNewDoc((const xmlChar*)"1.0");
-						xmlNode *imported_node = xmlDocCopyNode(const_cast<xmlNode*>((*search_node)->cobj()), search_tree, true);
-						if (imported_node) {
-							xmlDocSetRootElement(search_tree, imported_node);
-							xmlChar *buffer = 0;
-							int length = 0;
-							xmlDocDumpFormatMemoryEnc(search_tree, &buffer, &length, 0, 0);
-							if (buffer) {
-								new SongListSearch(ustring((char*)buffer), name->get_value());
-								xmlFree(buffer);
-							}
-						}
-#endif
 					}
 				} else {
 					SongListMutable *sl;
@@ -441,7 +457,7 @@ void Roboradio::State::done_loading ()
 {
 	tree.reset();
 
-	save_alarm.signal_alarm().connect(SigC::slot(*this, &State::on_save_alarm));
+	save_alarm.signal_alarm().connect(sigc::mem_fun(*this, &State::on_save_alarm));
 	save_alarm.set_relative(save_interval);
 }
 
